package com.ylx.web.controller.massage;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ylx.common.annotation.Log;
import com.ylx.common.core.domain.R;
import com.ylx.common.enums.BusinessType;
import com.ylx.common.exception.ServiceException;
import com.ylx.massage.domain.TJs;
import com.ylx.massage.domain.vo.TJsVo;
import com.ylx.massage.service.TJsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;


import javax.annotation.Resource;
import java.util.List;

/**
 * 技师Controller
 *
 * @author ylx
 * @date 2024-03-22
 */
@RestController
@RequestMapping("api/js/v1")
@Api(tags = {"技师管理"})
@Slf4j
public class TJsController {
    @Resource
    private TJsService jsService;

    /**
     * 添加技师申请
     *
     * @param js
     * @return
     */
    @Log(title = "技师管理", businessType = BusinessType.INSERT)
    @RequestMapping(value = "wx/add", method = RequestMethod.POST)
    @ApiOperation("添加技师申请")
    public R add(@RequestBody TJs js) {
        try {
            return R.ok(jsService.addJs(js));
        } catch (ServiceException s) {
            log.error(s.toString());
            return R.fail(s.getMessage());
        } catch (Exception e) {
            log.error(e.toString());
            return R.fail("系统异常");
        }

    }

    /**
     * 更新技师信息
     *
     * @param js
     * @return
     */
    @Log(title = "技师管理", businessType = BusinessType.UPDATE)
    @RequestMapping(value = "wx/update", method = RequestMethod.POST)
    @ApiOperation("更新技师信息")
    public Boolean wxUpdate(@RequestBody TJs js) {
        return jsService.updateById(js);
    }

    /**
     * 微信查询
     *
     * @param param
     * @return
     */
    @RequestMapping(value = "wx/select", method = RequestMethod.POST)
    @ApiOperation("微信查询")
    public List<TJs> wxSelect(@RequestBody TJsVo param) {
        return jsService.getAll(param);
    }


    /**
     * 分页查询数据
     */
    @RequestMapping(value = "/select", method = RequestMethod.GET)
    @ApiOperation("分页查询数据")
    public Page<TJs> selectSp(Page<TJs> page, TJs js) {
        LambdaQueryWrapper<TJs> mhCompanyLambdaQueryWrapper = new LambdaQueryWrapper<>();
        mhCompanyLambdaQueryWrapper.eq(null != js.getnTong(), TJs::getnTong, js.getnTong()).
                like(StringUtils.isNotBlank(js.getcName()), TJs::getcName, js.getcName()).
                orderByDesc(TJs::getDtCreateTime);
        return jsService.page(page, mhCompanyLambdaQueryWrapper);
    }


    /**
     * 删除
     */
    @Log(title = "技师管理", businessType = BusinessType.DELETE)
    @RequestMapping(value = "/del", method = RequestMethod.POST)
    @ApiOperation("删除")
    public Boolean del(@RequestBody TJs js) {
        return jsService.removeById(js);
    }

    @ApiOperation("根据id查询技师")
    @RequestMapping(value = "/wx/getByid", method = RequestMethod.POST)
    public R getById(@RequestBody TJs js) {
        return R.ok(jsService.getById(js.getcOpenId()));
    }
}
